@@ -55,7 +55,14 @@ import re
 import operator
 
 __all__ = ['get', 'get_all']
-__version__ = '1.1'
+__version__ = '1.2'
+
+
+# Make it work both in python 2.x and 3.x
+try:
+    basestring
+except NameError:
+    basestring = str
 
 
 def _pop_token(tokens):
@@ -291,17 +298,23 @@ class EllipsisToken(Token):
                     data = data.values()
                 except AttributeError:
                     pass
+                orig_data = data
                 try:
                     # Skip non-iterable datatypes.
                     data = iter(data)
                 except TypeError:
                     continue
                 for item in data:
-                    if not isinstance(item, str):
+                    if isinstance(item, basestring):
                         # Strings are nasty, because they can be iterated
                         # recursively idefinitely.
-                        stack.append(item)
-                        yield item
+                        continue
+                    if item is orig_data:
+                        # We are iterating over something that behaves like
+                        # the strings, refuse to descend.
+                        break
+                    stack.append(item)
+                    yield item
         token = _pop_token(tokens)
         for item in dive(data):
             try:
